==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/EditRowDefinitionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { EditRowDefinitionDescription } from "./EditRowDefinitionDescription";
/**
 * @hidden
 */
export let EditRowDefinitionDescriptionMetadata = /*@__PURE__*/ (() => {
    class EditRowDefinitionDescriptionMetadata extends Base {
        static b(a) {
            if (EditRowDefinitionDescriptionMetadata.a == null) {
                EditRowDefinitionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                EditRowDefinitionDescriptionMetadata.c(EditRowDefinitionDescriptionMetadata.a);
            }
            if (a.j(EditRowDefinitionDescriptionMetadata.a)) {
                return;
            }
            a.y(EditRowDefinitionDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            EditRowDefinitionDescriptionMetadata.b(a);
            a.aa("EditRowDefinition", () => new EditRowDefinitionDescription());
            a.z("EditRowDefinition", EditRowDefinitionDescriptionMetadata.a);
        }
    }
    EditRowDefinitionDescriptionMetadata.$t = /*@__PURE__*/ markType(EditRowDefinitionDescriptionMetadata, 'EditRowDefinitionDescriptionMetadata');
    EditRowDefinitionDescriptionMetadata.a = null;
    return EditRowDefinitionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/EditRowDefinitionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { EditRowDefinitionDescription } from "./EditRowDefinitionDescription";
/**
 * @hidden
 */
export let EditRowDefinitionDescriptionMetadata = /*@__PURE__*/ (() => {
    class EditRowDefinitionDescriptionMetadata extends Base {
        static b(a) {
            if (EditRowDefinitionDescriptionMetadata.a == null) {
                EditRowDefinitionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                EditRowDefinitionDescriptionMetadata.c(EditRowDefinitionDescriptionMetadata.a);
            }
            if (a.k(EditRowDefinitionDescriptionMetadata.a)) {
                return;
            }
            a.aa(EditRowDefinitionDescriptionMetadata.a);
        }
        static c(a) {
            DefinitionBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            EditRowDefinitionDescriptionMetadata.b(a);
            a.ac("EditRowDefinition", () => new EditRowDefinitionDescription());
            a.ab("EditRowDefinition", EditRowDefinitionDescriptionMetadata.a);
        }
    }
    EditRowDefinitionDescriptionMetadata.$t = /*@__PURE__*/ markType(EditRowDefinitionDescriptionMetadata, 'EditRowDefinitionDescriptionMetadata');
    EditRowDefinitionDescriptionMetadata.a = null;
    return EditRowDefinitionDescriptionMetadata;
})();
